@@ -148,15 +148,15 @@ class Console(cmd.Cmd):
             self.__printVersion()
             return
 
+        if self.__options.clear_cache:
+            self.__rs.clearCache()
+
         if self.__options.file:
             self.__loadFile(self.__options.file)
 
         if self.__options.console:
             self.cmdloop()
 
-        if self.__options.clear_cache:
-            self.__rs.clearCache()
-
         self.__handleOptions(self.__options)
 
     def __updatePrompt(self):
@@ -175,6 +175,9 @@ class Console(cmd.Cmd):
             
             self.__currentFileName = file
             self.__updatePrompt()
+
+            if not self.__options.no_load and self.__options.console:
+                self.__loadGadgets()
         except BaseException as e:
             raise RopperError(e)
         self.__rs.setImageBaseFor(file, self.__options.I)
@@ -443,7 +446,7 @@ class Console(cmd.Cmd):
         elif options.chain:
             self.__loadGadgets()
             self.__generateChain(options.chain)
-        else:
+        elif self.__options.file:
             self.__loadGadgets()
             if options.search:
                 self.__search(options.search, options.quality)
@@ -882,7 +885,6 @@ nx\t- Clears the NX-Flag (ELF|PE)"""
             arch = text[:index]
             text = text[index:].strip()
             arch = getArchitecture(arch)
-        import pdb;pdb.set_trace()
         if not arch:
             if self.__currentFileName:
                 arch = str(self.currentFile.arch)
